import { Query } from '@nestjs-query/core';
import { DeleteQueryBuilder, Repository, SelectQueryBuilder, UpdateQueryBuilder } from 'typeorm';
import { WhereBuilder } from './where.builder';
import { AbstractQueryBuilder } from './query-builder.abstract';
/**
 * @internal
 *
 * Class that will convert a Query into a `typeorm` Query Builder.
 */
export declare class FilterQueryBuilder<Entity> extends AbstractQueryBuilder<Entity> {
    readonly repo: Repository<Entity>;
    readonly whereBuilder: WhereBuilder<Entity>;
    constructor(repo: Repository<Entity>, whereBuilder?: WhereBuilder<Entity>);
    /**
     * Create a `typeorm` SelectQueryBuilder with `WHERE`, `ORDER BY` and `LIMIT/OFFSET` clauses.
     *
     * @param query - the query to apply.
     */
    select(query: Query<Entity>): SelectQueryBuilder<Entity>;
    /**
     * Create a `typeorm` DeleteQueryBuilder with a WHERE clause.
     *
     * @param query - the query to apply.
     */
    delete(query: Query<Entity>): DeleteQueryBuilder<Entity>;
    /**
     * Create a `typeorm` UpdateQueryBuilder with `WHERE` and `ORDER BY` clauses
     *
     * @param query - the query to apply.
     */
    update(query: Query<Entity>): UpdateQueryBuilder<Entity>;
    /**
     * Applies paging to a Pageable `typeorm` query builder
     * @param qb - the `typeorm` QueryBuilder
     * @param paging - the Paging options.
     */
    private applyPaging;
    /**
     * Applies the filter from a Query to a `typeorm` QueryBuilder.
     *
     * @param qb - the `typeorm` QueryBuilder.
     * @param filter - the filter.
     */
    private applyFilter;
    /**
     * Applies the ORDER BY clause to a `typeorm` QueryBuilder.
     * @param qb - the `typeorm` QueryBuilder.
     * @param sorts - an array of SortFields to create the ORDER BY clause.
     */
    private applySorting;
    /**
     * Create a `typeorm` SelectQueryBuilder which can be used as an entry point to create update, delete or insert
     * QueryBuilders.
     */
    private createQueryBuilder;
}
