import { EntityMetadata, Repository } from 'typeorm';
/**
 * @internal
 *
 * Base class for all QueryBuilders.
 */
export declare abstract class AbstractQueryBuilder<Entity> {
    readonly repository: Repository<Entity>;
    readonly entityMetadata: EntityMetadata;
    protected constructor(repository: Repository<Entity>);
    /**
     * Convert a field to the typeorm column name.
     *
     * @param field - the property name on the entity.
     */
    fieldToDbCol<F extends keyof Entity>(field: F): string;
    /**
     * Escapes a string to be safe to in a query.
     * @param str - the string to escape.
     */
    private escape;
}
