"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @internal
 *
 * Base class for all QueryBuilders.
 */
class AbstractQueryBuilder {
    constructor(repository) {
        this.repository = repository;
        this.entityMetadata = this.repository.metadata;
    }
    /**
     * Convert a field to the typeorm column name.
     *
     * @param field - the property name on the entity.
     */
    fieldToDbCol(field) {
        const colMetaData = this.entityMetadata.findColumnWithPropertyName(field);
        if (!colMetaData) {
            return this.escape(field);
        }
        return this.escape(colMetaData.databasePath);
    }
    /**
     * Escapes a string to be safe to in a query.
     * @param str - the string to escape.
     */
    escape(str) {
        return this.repository.manager.connection.driver.escape(str);
    }
}
exports.AbstractQueryBuilder = AbstractQueryBuilder;
//# sourceMappingURL=query-builder.abstract.js.map